@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: profunctors
 version: 5.2
-id: profunctors-5.2-9a29145c6a42bab58852d072f6668ae3
-key: profu_2CmtYbnZzSI32wE7lp4LJt
+id: profunctors-5.2-dcebd670a79351324a9f8d71a72c88e3
+key: profu_EsFQssGKUvQ2ZN47Ban4iz
 license: BSD3
 copyright: Copyright (C) 2011-2015 Edward A. Kmett
 maintainer: Edward A. Kmett <ekmett@gmail.com>
@@ -27,15 +27,15 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/profunctors-5.2
 library-dirs: /usr/lib/ghc-7.10.3/site-local/profunctors-5.2
 data-dir: /usr/share/arm-linux-ghc-7.10.3/profunctors-5.2
-hs-libraries: HSprofunctors-5.2-2CmtYbnZzSI32wE7lp4LJt
+hs-libraries: HSprofunctors-5.2-EsFQssGKUvQ2ZN47Ban4iz
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    base-orphans-0.5.0-a13c08e02979420be3bfcfc755842cf4
-    bifunctors-5.2-619b831167660978b6565dca15515574
-    comonad-5-e53ff69c5983127cf4f20e90dd6b5c9a
-    contravariant-1.4-9027be8359ae8a89877802024c295de2
-    distributive-0.5.0.2-921805b919081e64e9b7d8c792bc35e0
-    tagged-0.8.2-849e3b2865ae1877e32ec9d4d01c3d0a
+    base-orphans-0.5.3-27215a9428d23686c8514fbd3bba8ccb
+    bifunctors-5.2.1-854727fccb4481ffefcc20f535d6c50b
+    comonad-5-a91321d086a2de4a04a44d60c347669e
+    contravariant-1.4-7b1149a75def92c79deb23a86e0b36cb
+    distributive-0.5.0.2-6c580c91b8bf5de803bfa850eb262f37
+    tagged-0.8.3-aa128de4449752177a05765fb0ce3959
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
 haddock-interfaces: /usr/share/doc/haskell-profunctors/html/profunctors.haddock
 haddock-html: /usr/share/doc/haskell-profunctors/html
